@@ -40,6 +40,7 @@
 #include <telepathy-logger/log-manager.h>
 #include <libempathy/empathy-contact-list.h>
 #include <libempathy/empathy-gsettings.h>
+#include <libempathy/empathy-keyring.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-dispatcher.h>
 #include <libempathy/empathy-marshal.h>
@@ -55,6 +56,7 @@
 #include "empathy-smiley-manager.h"
 #include "empathy-ui-utils.h"
 #include "empathy-string-parser.h"
+#include "extensions/extensions.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_CHAT
 #include <libempathy/empathy-debug.h>
@@ -663,6 +665,17 @@ OUT:
 }
 #endif
 
+static gboolean
+nick_command_supported (EmpathyChat *chat)
+{
+	EmpathyChatPriv * priv = GET_PRIV (chat);
+	TpConnection    *connection;
+
+	connection = empathy_tp_chat_get_connection (priv->tp_chat);
+	return tp_proxy_has_interface_by_id (connection,
+		EMP_IFACE_QUARK_CONNECTION_INTERFACE_RENAMING);
+}
+
 static void
 chat_command_clear (EmpathyChat *chat,
 		    GStrv        strv)
@@ -762,24 +775,28 @@ chat_command_msg (EmpathyChat *chat,
 }
 #endif
 
+static void
+callback_for_request_rename (TpProxy *proxy,
+		  const GError *error,
+		  gpointer user_data,
+		  GObject *weak_object)
+{
+	if (error != NULL) {
+		DEBUG ("Call to RequestRename method failed: %s",error->message);
+	}
+}
+
 static void
 chat_command_nick (EmpathyChat *chat,
 		   GStrv        strv)
 {
 	EmpathyChatPriv *priv = GET_PRIV (chat);
-	TpConnection *connection;
-	GHashTable *new_alias;
-	TpHandle handle;
+	TpProxy *proxy;
 
-	connection = tp_account_get_connection (priv->account);
-	handle = tp_connection_get_self_handle (connection);
-	new_alias = g_hash_table_new (g_direct_hash, g_direct_equal);
-	g_hash_table_insert (new_alias, GUINT_TO_POINTER (handle), strv[1]);
+	proxy = TP_PROXY (tp_account_get_connection (priv->account));
 
-	tp_cli_connection_interface_aliasing_call_set_aliases (connection, -1,
-		new_alias, NULL, NULL, NULL, NULL);
-
-	g_hash_table_destroy (new_alias);
+	emp_cli_connection_interface_renaming_call_request_rename (proxy, -1,
+		strv[1], callback_for_request_rename, NULL, NULL, NULL);
 }
 
 static void
@@ -816,43 +833,44 @@ typedef struct {
 	guint min_parts;
 	guint max_parts;
 	ChatCommandFunc func;
+	gboolean (*is_supported)(EmpathyChat *chat);
 	const gchar *help;
 } ChatCommandItem;
 
 static ChatCommandItem commands[] = {
-	{"clear", 1, 1, chat_command_clear,
+	{"clear", 1, 1, chat_command_clear, NULL,
 	 N_("/clear: clear all messages from the current conversation")},
 
-	{"topic", 2, 2, chat_command_topic,
+	{"topic", 2, 2, chat_command_topic, NULL,
 	 N_("/topic <topic>: set the topic of the current conversation")},
 
-	{"join", 2, 2, chat_command_join,
+	{"join", 2, 2, chat_command_join, NULL,
 	 N_("/join <chat room ID>: join a new chat room")},
 
-	{"j", 2, 2, chat_command_join,
+	{"j", 2, 2, chat_command_join, NULL,
 	 N_("/j <chat room ID>: join a new chat room")},
 
 #if 0
 /* FIXME: https://bugzilla.gnome.org/show_bug.cgi?id=623682 */
-	{"query", 2, 3, chat_command_query,
+	{"query", 2, 3, chat_command_query, NULL,
 	 N_("/query <contact ID> [<message>]: open a private chat")},
 
-	{"msg", 3, 3, chat_command_msg,
+	{"msg", 3, 3, chat_command_msg, NULL,
 	 N_("/msg <contact ID> <message>: open a private chat")},
 #endif
 
-	{"nick", 2, 2, chat_command_nick,
+	{"nick", 2, 2, chat_command_nick, nick_command_supported,
 	 N_("/nick <nickname>: change your nickname on the current server")},
 
-	{"me", 2, 2, chat_command_me,
+	{"me", 2, 2, chat_command_me, NULL,
 	 N_("/me <message>: send an ACTION message to the current conversation")},
 
-	{"say", 2, 2, chat_command_say,
+	{"say", 2, 2, chat_command_say, NULL,
 	 N_("/say <message>: send <message> to the current conversation. "
 	    "This is used to send a message starting with a '/'. For example: "
 	    "\"/say /join is used to join a new chat room\"")},
 
-	{"help", 1, 2, chat_command_help,
+	{"help", 1, 2, chat_command_help, NULL,
 	 N_("/help [<command>]: show all supported commands. "
 	    "If <command> is defined, show its usage.")},
 };
@@ -872,20 +890,33 @@ static void
 chat_command_help (EmpathyChat *chat,
 		   GStrv        strv)
 {
+	EmpathyChatPriv *priv;
 	guint i;
 
+	priv = GET_PRIV (chat);
+
 	/* If <command> part is not defined,
 	 * strv[1] will be the terminal NULL */
 	if (strv[1] == NULL) {
 		for (i = 0; i < G_N_ELEMENTS (commands); i++) {
-			empathy_chat_view_append_event (chat->view,
-				_(commands[i].help));
+			if (commands[i].is_supported != NULL) {
+				if (!commands[i].is_supported (chat)) {
+					continue;
+				}
+			}
+		    empathy_chat_view_append_event (chat->view,
+			    _(commands[i].help));
 		}
 		return;
 	}
 
 	for (i = 0; i < G_N_ELEMENTS (commands); i++) {
 		if (g_ascii_strcasecmp (strv[1], commands[i].prefix) == 0) {
+			if (commands[i].is_supported != NULL) {
+				if (!commands[i].is_supported (chat)) {
+					break;
+				}
+			}
 			chat_command_show_help (chat, &commands[i]);
 			return;
 		}
@@ -981,6 +1012,11 @@ chat_send (EmpathyChat  *chat,
 			if (c != '\0' && !g_ascii_isspace (c)) {
 				continue;
 			}
+			if (commands[i].is_supported != NULL) {
+				if (!commands[i].is_supported (chat)) {
+					continue;
+				}
+			}
 
 			/* We can't use g_strsplit here because it does
 			 * not deal correctly if we have more than one space
@@ -2928,15 +2964,125 @@ empathy_chat_get_tp_chat (EmpathyChat *chat)
 	return priv->tp_chat;
 }
 
-static void display_password_info_bar (EmpathyChat *self,
-				       gboolean retry);
+typedef struct
+{
+	EmpathyChat *self;
+	GtkWidget *info_bar;
+	gulong response_id;
+	GtkWidget *button;
+	GtkWidget *label;
+	GtkWidget *entry;
+	GtkWidget *spinner;
+	gchar *password;
+} PasswordData;
+
+static void
+passwd_remember_button_cb (GtkButton *button,
+			  PasswordData *data)
+{
+	gtk_info_bar_response (GTK_INFO_BAR (data->info_bar), GTK_RESPONSE_OK);
+}
+
+static void
+passwd_not_now_button_cb (GtkButton *button,
+			  PasswordData *data)
+{
+	gtk_info_bar_response (GTK_INFO_BAR (data->info_bar), GTK_RESPONSE_NO);
+}
+
+static void
+remember_password_infobar_response_cb (GtkWidget *info_bar,
+				       gint response_id,
+				       PasswordData *data)
+{
+	EmpathyChatPriv *priv = GET_PRIV (data->self);
+
+	if (response_id == GTK_RESPONSE_OK) {
+		DEBUG ("Saving room password");
+		empathy_keyring_set_room_password_async (priv->account,
+							 empathy_tp_chat_get_id (priv->tp_chat),
+							 data->password,
+							 NULL, NULL);
+	}
+
+	gtk_widget_destroy (info_bar);
+	g_free (data->password);
+	g_slice_free (PasswordData, data);
+}
+
+static void
+chat_prompt_to_save_password (EmpathyChat *self,
+			      PasswordData *data)
+{
+	GtkWidget *content_area;
+	GtkWidget *hbox;
+	GtkWidget *image;
+	GtkWidget *label;
+	GtkWidget *alig;
+	GtkWidget *button;
+
+	/* save the password in case it needs to be saved */
+	data->password = g_strdup (gtk_entry_get_text (GTK_ENTRY (data->entry)));
+
+	/* Remove all previous widgets */
+	content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (data->info_bar));
+	gtk_container_forall (GTK_CONTAINER (content_area),
+			      (GtkCallback) gtk_widget_destroy, NULL);
+	data->button = NULL;
+	data->label = NULL;
+	data->entry = NULL;
+	data->spinner = NULL;
+
+	gtk_info_bar_set_message_type (GTK_INFO_BAR (data->info_bar),
+				       GTK_MESSAGE_QUESTION);
+
+	hbox = gtk_hbox_new (FALSE, 5);
+	gtk_box_pack_start (GTK_BOX (content_area), hbox, TRUE, TRUE, 0);
+
+	/* Add image */
+	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_AUTHENTICATION,
+					  GTK_ICON_SIZE_DIALOG);
+	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+
+	/* Add message */
+	label = gtk_label_new (_("Would you like to store this password?"));
+	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+
+	/* Add 'Remember' button */
+	alig = gtk_alignment_new (0, 0.5, 1, 0);
+
+	button = gtk_button_new_with_label (_("Remember"));
+	gtk_container_add (GTK_CONTAINER (alig), button);
+	gtk_box_pack_start (GTK_BOX (hbox), alig, FALSE, FALSE, 0);
+
+	g_signal_connect (button, "clicked", G_CALLBACK (passwd_remember_button_cb),
+			  data);
+
+	/* Add 'Not now' button */
+	alig = gtk_alignment_new (0, 0.5, 1, 0);
+
+	button = gtk_button_new_with_label (_("Not now"));
+	gtk_container_add (GTK_CONTAINER (alig), button);
+	gtk_box_pack_start (GTK_BOX (hbox), alig, FALSE, FALSE, 0);
+
+	g_signal_connect (button, "clicked", G_CALLBACK (passwd_not_now_button_cb),
+			  data);
+
+	/* go! */
+	g_signal_handler_disconnect (data->info_bar, data->response_id);
+	g_signal_connect (data->info_bar, "response",
+			  G_CALLBACK (remember_password_infobar_response_cb), data);
+
+	gtk_widget_show_all (data->info_bar);
+}
 
 static void
 provide_password_cb (GObject *tp_chat,
 		     GAsyncResult *res,
 		     gpointer user_data)
 {
-	EmpathyChat *self = EMPATHY_CHAT (user_data);
+	PasswordData *data = user_data;
+	EmpathyChat *self = data->self;
 	EmpathyChatPriv *priv = GET_PRIV (self);
 	GError *error = NULL;
 
@@ -2945,12 +3091,43 @@ provide_password_cb (GObject *tp_chat,
 		DEBUG ("error: %s", error->message);
 		/* FIXME: what should we do if that's another error? Close the channel?
 		 * Display the raw D-Bus error to the user isn't very useful */
-		if (g_error_matches (error, TP_ERRORS, TP_ERROR_AUTHENTICATION_FAILED))
-			display_password_info_bar (self, TRUE);
+		if (g_error_matches (error, TP_ERRORS, TP_ERROR_AUTHENTICATION_FAILED)) {
+			/* entry */
+			gtk_entry_set_text (GTK_ENTRY (data->entry), "");
+			gtk_widget_set_sensitive (data->entry, TRUE);
+			gtk_widget_grab_focus (data->entry);
+
+			/* info bar */
+			gtk_info_bar_set_message_type (
+			    GTK_INFO_BAR (data->info_bar),
+			    GTK_MESSAGE_ERROR);
+
+			/* button */
+			gtk_widget_set_sensitive (data->button, TRUE);
+			gtk_button_set_label (GTK_BUTTON (data->button),
+			    _("Retry"));
+
+			/* label */
+			gtk_label_set_text (GTK_LABEL (data->label),
+			    _("Wrong password; please try again:"));
+
+			/* spinner */
+			gtk_spinner_stop (GTK_SPINNER (data->spinner));
+			gtk_widget_hide (data->spinner);
+		}
 		g_error_free (error);
 		return;
 	}
 
+	if (empathy_keyring_is_available ()) {
+		/* ask whether they want to save the password */
+		chat_prompt_to_save_password (self, data);
+	} else {
+		/* Get rid of the password info bar finally */
+		gtk_widget_destroy (data->info_bar);
+		g_slice_free (PasswordData, data);
+	}
+
 	/* Room joined */
 	gtk_widget_set_sensitive (priv->hpaned, TRUE);
 	gtk_widget_grab_focus (self->input_text_view);
@@ -2959,44 +3136,66 @@ provide_password_cb (GObject *tp_chat,
 static void
 password_infobar_response_cb (GtkWidget *info_bar,
 			      gint response_id,
-			      EmpathyChat *self)
+			      PasswordData *data)
 {
-	EmpathyChatPriv *priv = GET_PRIV (self);
-	GtkWidget *entry;
+	EmpathyChatPriv *priv = GET_PRIV (data->self);
 	const gchar *password;
 
-	if (response_id != GTK_RESPONSE_OK)
-		goto out;
+	if (response_id != GTK_RESPONSE_OK) {
+		gtk_widget_destroy (info_bar);
+		g_slice_free (PasswordData, data);
+		return;
+	}
 
-	entry = g_object_get_data (G_OBJECT (info_bar), "password-entry");
-	g_assert (entry != NULL);
-
-	password = gtk_entry_get_text (GTK_ENTRY (entry));
+	password = gtk_entry_get_text (GTK_ENTRY (data->entry));
 
 	empathy_tp_chat_provide_password_async (priv->tp_chat, password,
-						provide_password_cb, self);
+						provide_password_cb, data);
 
- out:
-	gtk_widget_destroy (info_bar);
+	gtk_widget_set_sensitive (data->button, FALSE);
+	gtk_widget_set_sensitive (data->entry, FALSE);
+
+	gtk_spinner_start (GTK_SPINNER (data->spinner));
+	gtk_widget_show (data->spinner);
 }
 
 static void
 password_entry_activate_cb (GtkWidget *entry,
-			  GtkWidget *info_bar)
+			  PasswordData *data)
 {
-	gtk_info_bar_response (GTK_INFO_BAR (info_bar), GTK_RESPONSE_OK);
+	gtk_info_bar_response (GTK_INFO_BAR (data->info_bar), GTK_RESPONSE_OK);
 }
 
 static void
 passwd_join_button_cb (GtkButton *button,
-			  GtkWidget *info_bar)
+			  PasswordData *data)
 {
-	gtk_info_bar_response (GTK_INFO_BAR (info_bar), GTK_RESPONSE_OK);
+	gtk_info_bar_response (GTK_INFO_BAR (data->info_bar), GTK_RESPONSE_OK);
 }
 
 static void
-display_password_info_bar (EmpathyChat *self,
-			   gboolean retry)
+clear_icon_released_cb (GtkEntry *entry,
+			GtkEntryIconPosition icon_pos,
+			GdkEvent *event,
+			PasswordData *data)
+{
+	gtk_entry_set_text (entry, "");
+}
+
+static void
+password_entry_changed_cb (GtkEditable *entry,
+			   PasswordData *data)
+{
+	const gchar *str;
+
+	str = gtk_entry_get_text (GTK_ENTRY (entry));
+
+	gtk_entry_set_icon_sensitive (GTK_ENTRY (entry),
+	    GTK_ENTRY_ICON_SECONDARY, !EMP_STR_EMPTY (str));
+}
+
+static void
+display_password_info_bar (EmpathyChat *self)
 {
 	EmpathyChatPriv *priv = GET_PRIV (self);
 	GtkWidget *info_bar;
@@ -3007,29 +3206,19 @@ display_password_info_bar (EmpathyChat *self,
 	GtkWidget *entry;
 	GtkWidget *alig;
 	GtkWidget *button;
-	GtkMessageType type;
-	const gchar *msg, *button_label;
+	GtkWidget *spinner;
+	PasswordData *data;
 
-	if (retry) {
-		/* Previous password was wrong */
-		type = GTK_MESSAGE_ERROR;
-		msg = _("Wrong password; please try again:");
-		button_label = _("Retry");
-	}
-	else {
-		/* First time we're trying to join */
-		type = GTK_MESSAGE_QUESTION;
-		msg = _("This room is protected by a password:");
-		button_label = _("Join");
-	}
+	data = g_slice_new0 (PasswordData);
 
 	info_bar = gtk_info_bar_new ();
-	gtk_info_bar_set_message_type (GTK_INFO_BAR (info_bar), type);
+	gtk_info_bar_set_message_type (GTK_INFO_BAR (info_bar),
+	    GTK_MESSAGE_QUESTION);
 
 	content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (info_bar));
 
-	hbox = gtk_hbox_new (FALSE, 3);
-	gtk_container_add (GTK_CONTAINER (content_area), hbox);
+	hbox = gtk_hbox_new (FALSE, 5);
+	gtk_box_pack_start (GTK_BOX (content_area), hbox, TRUE, TRUE, 0);
 
 	/* Add image */
 	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_AUTHENTICATION,
@@ -3037,7 +3226,7 @@ display_password_info_bar (EmpathyChat *self,
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
 	/* Add message */
-	label = gtk_label_new (msg);
+	label = gtk_label_new (_("This room is protected by a password:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 	/* Add password entry */
@@ -3045,32 +3234,107 @@ display_password_info_bar (EmpathyChat *self,
 	gtk_entry_set_visibility (GTK_ENTRY (entry), FALSE);
 	gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
 
+	gtk_entry_set_icon_from_stock (GTK_ENTRY (entry),
+				       GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_CLEAR);
+	gtk_entry_set_icon_sensitive (GTK_ENTRY (entry),
+				      GTK_ENTRY_ICON_SECONDARY, FALSE);
+
+	g_signal_connect (entry, "icon-release",
+			  G_CALLBACK (clear_icon_released_cb), data);
+	g_signal_connect (entry, "changed",
+			  G_CALLBACK (password_entry_changed_cb), data);
+
 	g_signal_connect (entry, "activate",
-			  G_CALLBACK (password_entry_activate_cb), info_bar);
+			  G_CALLBACK (password_entry_activate_cb), data);
 
 	/* Focus the password entry once it's realized */
 	g_signal_connect (entry, "realize", G_CALLBACK (gtk_widget_grab_focus), NULL);
 
 	/* Add 'Join' button */
-	alig = gtk_alignment_new (0, 0.5, 0, 0);
+	alig = gtk_alignment_new (0, 0.5, 1, 0);
 
-	button = gtk_button_new_with_label (button_label);
+	button = gtk_button_new_with_label (_("Join"));
 	gtk_container_add (GTK_CONTAINER (alig), button);
 	gtk_box_pack_start (GTK_BOX (hbox), alig, FALSE, FALSE, 0);
 
 	g_signal_connect (button, "clicked", G_CALLBACK (passwd_join_button_cb),
-			  info_bar);
+			  data);
 
-	g_object_set_data (G_OBJECT (info_bar), "password-entry", entry);
+	/* Add spinner */
+	spinner = gtk_spinner_new ();
+	gtk_box_pack_end (GTK_BOX (hbox), spinner, FALSE, FALSE, 0);
+
+	/* Save some data for messing around with later */
+	data->self = self;
+	data->info_bar = info_bar;
+	data->button = button;
+	data->label = label;
+	data->entry = entry;
+	data->spinner = spinner;
 
 	gtk_box_pack_start (GTK_BOX (priv->info_bar_vbox), info_bar,
-			    FALSE, FALSE, 3);
+			    TRUE, TRUE, 3);
 	gtk_widget_show_all (hbox);
 
-	g_signal_connect (info_bar, "response",
-			  G_CALLBACK (password_infobar_response_cb), self);
+	data->response_id = g_signal_connect (info_bar, "response",
+					      G_CALLBACK (password_infobar_response_cb), data);
 
 	gtk_widget_show_all (info_bar);
+	/* ... but hide the spinner */
+	gtk_widget_hide (spinner);
+}
+
+static void
+provide_saved_password_cb (GObject *tp_chat,
+			   GAsyncResult *res,
+			   gpointer user_data)
+{
+	EmpathyChat *self = user_data;
+	EmpathyChatPriv *priv = GET_PRIV (self);
+	GError *error = NULL;
+
+	if (!empathy_tp_chat_provide_password_finish (EMPATHY_TP_CHAT (tp_chat), res,
+						      &error)) {
+		DEBUG ("error: %s", error->message);
+		/* FIXME: what should we do if that's another error? Close the channel?
+		 * Display the raw D-Bus error to the user isn't very useful */
+		if (g_error_matches (error, TP_ERRORS, TP_ERROR_AUTHENTICATION_FAILED)) {
+			display_password_info_bar (self);
+			gtk_widget_set_sensitive (priv->hpaned, FALSE);
+		}
+		g_error_free (error);
+		return;
+	}
+
+	/* Room joined */
+	gtk_widget_set_sensitive (priv->hpaned, TRUE);
+	gtk_widget_grab_focus (self->input_text_view);
+}
+
+static void
+chat_room_got_password_cb (GObject *source,
+			   GAsyncResult *result,
+			   gpointer user_data)
+{
+	EmpathyChat *self = user_data;
+	EmpathyChatPriv *priv = GET_PRIV (self);
+	const gchar *password;
+	GError *error = NULL;
+
+	password = empathy_keyring_get_room_password_finish (priv->account,
+	    result, &error);
+
+	if (error != NULL) {
+		DEBUG ("Couldn't get room password: %s\n", error->message);
+		g_clear_error (&error);
+
+		display_password_info_bar (self);
+		gtk_widget_set_sensitive (priv->hpaned, FALSE);
+		return;
+	}
+
+	empathy_tp_chat_provide_password_async (priv->tp_chat, password,
+						provide_saved_password_cb, self);
 }
 
 static void
@@ -3079,8 +3343,9 @@ chat_password_needed_changed_cb (EmpathyChat *self)
 	EmpathyChatPriv *priv = GET_PRIV (self);
 
 	if (empathy_tp_chat_password_needed (priv->tp_chat)) {
-		display_password_info_bar (self, FALSE);
-		gtk_widget_set_sensitive (priv->hpaned, FALSE);
+		empathy_keyring_get_room_password_async (priv->account,
+							 empathy_tp_chat_get_id (priv->tp_chat),
+							 chat_room_got_password_cb, self);
 	}
 }
 
@@ -3089,7 +3354,6 @@ empathy_chat_set_tp_chat (EmpathyChat   *chat,
 			  EmpathyTpChat *tp_chat)
 {
 	EmpathyChatPriv *priv = GET_PRIV (chat);
-	TpConnection    *connection;
 	GPtrArray       *properties;
 
 	g_return_if_fail (EMPATHY_IS_CHAT (chat));
@@ -3105,7 +3369,6 @@ empathy_chat_set_tp_chat (EmpathyChat   *chat,
 	}
 
 	priv->tp_chat = g_object_ref (tp_chat);
-	connection = empathy_tp_chat_get_connection (priv->tp_chat);
 	priv->account = g_object_ref (empathy_tp_chat_get_account (priv->tp_chat));
 
 	g_signal_connect (tp_chat, "destroy",
