@@ -50,7 +50,6 @@
 #include <libempathy/empathy-debug.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-dispatcher.h>
-#include <libempathy/empathy-idle.h>
 #include <libempathy/empathy-ft-factory.h>
 
 void
@@ -232,8 +231,8 @@ empathy_icon_name_for_individual (FolksIndividual *individual)
 	TpConnectionPresenceType presence;
 
 	folks_presence =
-	    folks_has_presence_get_presence_type (
-	        FOLKS_HAS_PRESENCE (individual));
+	    folks_presence_owner_get_presence_type (
+	        FOLKS_PRESENCE_OWNER (individual));
 	presence = empathy_folks_presence_type_to_tp (folks_presence);
 
 	return empathy_icon_name_for_presence (presence);
@@ -634,7 +633,7 @@ empathy_pixbuf_avatar_from_individual_scaled_async (
 			empathy_pixbuf_avatar_from_individual_scaled_async);
 
 	avatar_file =
-		folks_has_avatar_get_avatar (FOLKS_HAS_AVATAR (individual));
+		folks_avatar_owner_get_avatar (FOLKS_AVATAR_OWNER (individual));
 	if (avatar_file == NULL)
 		goto out;
 
