@@ -135,8 +135,7 @@ struct _EmpathyCallWindowPriv
   GtkWidget *pane;
   GtkAction *redial;
   GtkAction *menu_fullscreen;
-  GtkAction *action_camera;
-  GtkAction *action_camera_preview;
+  GtkAction *action_camera_on;
   GtkWidget *tool_button_camera_off;
   GtkWidget *tool_button_camera_preview;
   GtkWidget *tool_button_camera_on;
@@ -839,7 +838,7 @@ disable_camera (EmpathyCallWindow *self)
 
   gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (
       priv->tool_button_camera_off), TRUE);
-  gtk_radio_action_set_current_value (GTK_RADIO_ACTION (priv->action_camera),
+  gtk_radio_action_set_current_value (GTK_RADIO_ACTION (priv->action_camera_on),
       CAMERA_STATE_OFF);
   unblock_camera_control_signals (self);
 
@@ -896,7 +895,7 @@ enable_preview (EmpathyCallWindow *self)
 
   gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (
         priv->tool_button_camera_preview), TRUE);
-  gtk_radio_action_set_current_value (GTK_RADIO_ACTION (priv->action_camera),
+  gtk_radio_action_set_current_value (GTK_RADIO_ACTION (priv->action_camera_on),
       CAMERA_STATE_PREVIEW);
   unblock_camera_control_signals (self);
 
@@ -952,7 +951,7 @@ enable_camera (EmpathyCallWindow *self)
 
   gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (
       priv->tool_button_camera_on), TRUE);
-  gtk_radio_action_set_current_value (GTK_RADIO_ACTION (priv->action_camera),
+  gtk_radio_action_set_current_value (GTK_RADIO_ACTION (priv->action_camera_on),
       CAMERA_STATE_ON);
   unblock_camera_control_signals (self);
 
@@ -1056,8 +1055,7 @@ empathy_call_window_init (EmpathyCallWindow *self)
     "camera_off", &priv->tool_button_camera_off,
     "camera_preview", &priv->tool_button_camera_preview,
     "camera_on", &priv->tool_button_camera_on,
-    "action_camera_off",  &priv->action_camera,
-    "action_camera_preview",  &priv->action_camera_preview,
+    "action_camera_on",  &priv->action_camera_on,
     "details_vbox",  &priv->details_vbox,
     "vcodec_encoding_label", &priv->vcodec_encoding_label,
     "acodec_encoding_label", &priv->acodec_encoding_label,
@@ -1084,7 +1082,7 @@ empathy_call_window_init (EmpathyCallWindow *self)
     "camera_off", "toggled", tool_button_camera_off_toggled_cb,
     "camera_preview", "toggled", tool_button_camera_preview_toggled_cb,
     "camera_on", "toggled", tool_button_camera_on_toggled_cb,
-    "action_camera_off", "changed", action_camera_change_cb,
+    "action_camera_on", "changed", action_camera_change_cb,
     NULL);
 
   gtk_action_set_sensitive (priv->menu_fullscreen, FALSE);
@@ -1949,6 +1947,7 @@ empathy_call_window_disconnected (EmpathyCallWindow *self,
 
       /* Unsensitive the camera and mic button */
       gtk_widget_set_sensitive (priv->tool_button_camera_on, FALSE);
+      gtk_action_set_sensitive (priv->action_camera_on, FALSE);
       gtk_widget_set_sensitive (priv->mic_button, FALSE);
 
       /* Be sure that the mic button is enabled */
@@ -2487,6 +2486,7 @@ empathy_call_window_connected (gpointer user_data)
       GTK_TOGGLE_TOOL_BUTTON (priv->tool_button_camera_on),
       priv->sending_video && priv->video_input != NULL);
   gtk_widget_set_sensitive (priv->tool_button_camera_on, can_send_video);
+  gtk_action_set_sensitive (priv->action_camera_on, can_send_video);
 
   gtk_action_set_sensitive (priv->redial, FALSE);
   gtk_widget_set_sensitive (priv->redial_button, FALSE);
@@ -2688,6 +2688,7 @@ empathy_call_window_remove_video_input (EmpathyCallWindow *self)
   priv->video_preview = NULL;
 
   gtk_widget_set_sensitive (priv->tool_button_camera_on, FALSE);
+  gtk_action_set_sensitive (priv->action_camera_on, FALSE);
   gtk_widget_set_sensitive (priv->tool_button_camera_preview, FALSE);
 }
 
@@ -3302,7 +3303,7 @@ block_camera_control_signals (EmpathyCallWindow *self)
       tool_button_camera_preview_toggled_cb, self);
   g_signal_handlers_block_by_func (priv->tool_button_camera_on,
       tool_button_camera_on_toggled_cb, self);
-  g_signal_handlers_block_by_func (priv->action_camera,
+  g_signal_handlers_block_by_func (priv->action_camera_on,
       action_camera_change_cb, self);
 }
 
@@ -3317,6 +3318,6 @@ unblock_camera_control_signals (EmpathyCallWindow *self)
       tool_button_camera_preview_toggled_cb, self);
   g_signal_handlers_unblock_by_func (priv->tool_button_camera_on,
       tool_button_camera_on_toggled_cb, self);
-  g_signal_handlers_unblock_by_func (priv->action_camera,
+  g_signal_handlers_unblock_by_func (priv->action_camera_on,
       action_camera_change_cb, self);
 }
