@@ -34,7 +34,6 @@
 #include <folks/folks.h>
 
 #include <libempathy/empathy-contact.h>
-#include <libempathy/empathy-idle.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-dispatcher.h>
 #include <libempathy/empathy-chatroom-manager.h>
@@ -51,6 +50,7 @@
 #include <libempathy-gtk/empathy-contact-list-store.h>
 #include <libempathy-gtk/empathy-contact-list-view.h>
 #include <libempathy-gtk/empathy-live-search.h>
+#include <libempathy-gtk/empathy-contact-search-dialog.h>
 #include <libempathy-gtk/empathy-geometry.h>
 #include <libempathy-gtk/empathy-gtk-enum-types.h>
 #include <libempathy-gtk/empathy-individual-dialogs.h>
@@ -532,8 +532,8 @@ main_window_row_deleted_cb (GtkTreeModel      *model,
 			gtk_label_set_markup (GTK_LABEL (priv->no_entry_label), tmp);
 			g_free (tmp);
 
-			gtk_label_set_ellipsize (GTK_LABEL (priv->no_entry_label),
-				PANGO_ELLIPSIZE_END);
+			gtk_label_set_line_wrap (GTK_LABEL (priv->no_entry_label),
+				TRUE);
 
 			gtk_notebook_set_current_page (
 					GTK_NOTEBOOK (priv->notebook), PAGE_NO_MATCH);
@@ -935,6 +935,15 @@ main_window_chat_add_contact_cb (GtkAction         *action,
 	empathy_new_individual_dialog_show (GTK_WINDOW (window));
 }
 
+static void
+main_window_chat_search_contacts_cb (GtkAction         *action,
+				     EmpathyMainWindow *window)
+{
+	GtkWidget *dialog = empathy_contact_search_dialog_new (
+			GTK_WINDOW (window));
+	gtk_widget_show (dialog);
+}
+
 static void
 main_window_view_show_ft_manager (GtkAction         *action,
 				  EmpathyMainWindow *window)
@@ -1779,6 +1788,7 @@ empathy_main_window_init (EmpathyMainWindow *window)
 			      "room_join_favorites", "activate", main_window_room_join_favorites_cb,
 			      "room_manage_favorites", "activate", main_window_room_manage_favorites_cb,
 			      "chat_add_contact", "activate", main_window_chat_add_contact_cb,
+			      "chat_search_contacts", "activate", main_window_chat_search_contacts_cb,
 			      "view_show_ft_manager", "activate", main_window_view_show_ft_manager,
 			      "view_show_offline", "toggled", main_window_view_show_offline_cb,
 			      "view_show_protocols", "toggled", main_window_view_show_protocols_cb,
